#include <Wire.h>
#include <LiquidCrystal_I2C.h>
#include <WiFi.h>
#include <HTTPClient.h>

#define StopButton_PIN 4

// ThingSpeak API details
const String thingSpeakChannelID = "2820820";  // Replace with your ThingSpeak Channel ID
const String thingSpeakAPIKey = "H5U3KB7Z7K207CUM";  // Replace with your ThingSpeak API Write Key

// Variables     
int stopButtonState = 0; 
int lastStopButtonState = 0;              
uint32_t storedPressurePA = 0;
uint32_t storedPressurePSI = 0;
uint32_t storedPressureKGF = 0;
int PressureCloud = 0;


// Tracking Flags
bool displayStopped = false; // Flag to indicate display is stopped

// Defined in another file
extern LiquidCrystal_I2C lcd;
extern float currentpressure;
extern unsigned long lastDebounceTime;
extern const unsigned long debounceDelay;
extern int unitIndex2;
extern float paValue;
extern float psiValue;
extern float kgfCm2Value;

// WiFi credentials
const char* ssid = "aq phone";
const char* password = "hxbx2499";

// Setup function
void StoreDatasetup(){
  pinMode(StopButton_PIN, INPUT_PULLUP);
  
  // Connect to WiFi
  Serial.print("Connecting to WiFi");
  WiFi.begin(ssid, password);
  while (WiFi.status() != WL_CONNECTED) {
    delay(1000);
    Serial.print(".");
  }
  Serial.println("Connected to WiFi");
}

// Loop function
void StoreDataloop() {
    unsigned long currentMillis = millis();

    // Handle Send Data Button
    stopButtonState = digitalRead(StopButton_PIN);
    if (stopButtonState == LOW && lastStopButtonState == HIGH && (currentMillis - lastDebounceTime > debounceDelay)) {
        lastDebounceTime = currentMillis; // Update debounce time

        Serial.print("Stored Pressure: ");
        Serial.println(storedPressurePA, 4); // Print with 4 decimal places for clarity
        clearRow(1);
        clearRow(2);
        clearRow(3);

        lcd.setCursor(2, 2);
        lcd.print("Sending Data: ");
        lcd.setCursor(5, 3);

        if (unitIndex2 == 1) {
           lcd.print((int)paValue);  // Display paValue as an integer (no decimal point)
           lcd.print(" Pa");
           storedPressurePA = currentpressure; // Store the current pressure
           PressureCloud = currentpressure;
        } else if (unitIndex2 == 2) {
            lcd.print(psiValue, 3); // Psi with 3 decimal places
            lcd.print(" Psi");
            storedPressurePSI = (currentpressure * 1000); // Store the current pressure
            PressureCloud = currentpressure * 0.000145038;
        } else if (unitIndex2 == 3) {
            lcd.print(kgfCm2Value, 3); // kgf/cm2 with 3 decimal places
            lcd.print(" kgf/cm2");
            storedPressureKGF = (currentpressure * 1000); // Store the current pressure
            PressureCloud = currentpressure 0.0000101972;
        }

        // Send Pressure over BLE 
        if (deviceConnected) {
               paCharacteristic->setValue(storedPressurePA);  // Example for PA
               paCharacteristic->notify();
               
               psiCharacteristic->setValue(storedPressurePSI);  // Example for PSI
               psiCharacteristic->notify();
               
               kgfCharacteristic->setValue(storedPressureKGF);  // Example for KGF
               kgfCharacteristic->notify();
               
               delay(1000);  // Adjust delay as needed
        }

        // Send Pressure to ThingSpeak
        if(WiFi.status() == WL_CONNECTED) {

            HTTPClient http;
            String url = "http://api.thingspeak.com/update?api_key=" + thingSpeakAPIKey;
            url += "&field1=" + String(PressureCloud); // Send storedPressurePA (adjust for your field number)
            //url += "&field2=" + String(storedPressurePSI); // Send storedPressurePSI (adjust for your field number)
            //url += "&field3=" + String(storedPressureKGF); // Send storedPressureKGF (adjust for your field number)

            http.begin(url);  // Specify the URL
            int httpResponseCode = http.GET();  // Make the GET request

            if (httpResponseCode > 0) {
                Serial.println("Data sent to ThingSpeak");
            } else {
                Serial.println("Error sending data to ThingSpeak");
            }
            http.end();  // Free the resources
        } else {
            Serial.println("WiFi not connected");
        }

        delay(7000); // Block delay, consider using millis() for non-blocking behavior
        clearRow(1);
        clearRow(2);
        clearRow(3);
    }

    lastStopButtonState = stopButtonState; // Update the last state
} 


